@@ -3,6 +3,7 @@ from typing import Optional
 
 from whispers.log import debug
 from whispers.plugins.config import Config
+from whispers.plugins.dockercfg import Dockercfg
 from whispers.plugins.dockerfile import Dockerfile
 from whispers.plugins.go import Go
 from whispers.plugins.html import Html
@@ -20,14 +21,16 @@ from whispers.plugins.python import Python
 from whispers.plugins.shell import Shell
 from whispers.plugins.xml import Xml
 from whispers.plugins.yml import Yml
+from whispers.rules import WhisperRules
 
 
 class WhisperPlugins:
-    def __init__(self, filename: str):
+    def __init__(self, filename: str, rules: WhisperRules):
         """Inits the rules objects. Call pairs() to get results"""
         self.filename = filename
         self.filepath = Path(filename)
         self.filetype = self.filepath.name.split(".")[-1]
+        self.rules = rules
         self.plugin = self.load_plugin()
 
     def load_plugin(self) -> Optional[object]:
@@ -42,20 +45,20 @@ class WhisperPlugins:
             self.filename = self.filepath.stem
             self.filetype = self.filename.split(".")[-1]
         if self.filetype in ["yaml", "yml"]:
-            return Yml()
+            return Yml(self.rules)
         elif self.filetype == "json":
-            return Json()
+            return Json(self.rules)
         elif self.filetype == "xml":
-            return Xml()
+            return Xml(self.rules)
         elif self.filetype.startswith("npmrc"):
             return Npmrc()
         elif self.filetype.startswith("pypirc"):
             return Pypirc()
         elif self.filepath.name == "pip.conf":
             return Pip()
-        elif self.filetype in ["conf", "cfg", "config", "ini", "env", "credentials"]:
+        elif self.filetype in ["conf", "cfg", "config", "ini", "env", "credentials", "s3cfg"]:
             if self.filepath.open("r").readline().startswith("<?xml "):
-                return Xml()
+                return Xml(self.rules)
             else:
                 return Config()
         elif self.filetype == "properties":
@@ -64,13 +67,15 @@ class WhisperPlugins:
             return Shell()
         elif self.filepath.name.startswith("Dockerfile"):
             return Dockerfile()
+        elif self.filetype == "dockercfg":
+            return Dockercfg()
         elif self.filetype.startswith("htpasswd"):
             return Htpasswd()
         elif self.filetype == "txt":
-            return Plaintext()
+            return Plaintext(self.rules)
         elif self.filetype.startswith("htm"):
             return Html()
-        elif self.filetype == "py":
+        elif self.filetype in ["py", "py3", "py35", "py36", "py37", "py38"]:
             return Python()
         elif self.filetype == "js":
             return Javascript()
